==> supplier-center-api-1.0.38-sources.jar: cn/com/duiba/supplier/center/api/request/order/SupplyOrderInfoRequest.java <==
package cn.com.duiba.supplier.center.api.request.order;

import java.io.Serializable;

/**
 * @author duiba
 */
public class SupplyOrderInfoRequest implements Serializable {
    private static final long serialVersionUID = 3169590830373150562L;

    /**
     * 采购单订单号 必填
     */
    private Long supplyOrderNum;
    /**
     * 供应商父订单号
     */
    private String supplierParentOrderId;
    /**
     * 供应商子订单号
     */
    private String supplierSubOrderId;
    /**
     * 分销商父订单号
     */
    private String distributorsParentOrderId;
    /**
     * 分销商子订单号
     */
    private String distributorsSubOrderId;

    public Long getSupplyOrderNum() {
        return supplyOrderNum;
    }

    public void setSupplyOrderNum(Long supplyOrderNum) {
        this.supplyOrderNum = supplyOrderNum;
    }

    public String getSupplierParentOrderId() {
        return supplierParentOrderId;
    }

    public void setSupplierParentOrderId(String supplierParentOrderId) {
        this.supplierParentOrderId = supplierParentOrderId;
    }

    public String getSupplierSubOrderId() {
        return supplierSubOrderId;
    }

    public void setSupplierSubOrderId(String supplierSubOrderId) {
        this.supplierSubOrderId = supplierSubOrderId;
    }

    public String getDistributorsParentOrderId() {
        return distributorsParentOrderId;
    }

    public void setDistributorsParentOrderId(String distributorsParentOrderId) {
        this.distributorsParentOrderId = distributorsParentOrderId;
    }

    public String getDistributorsSubOrderId() {
        return distributorsSubOrderId;
    }

    public void setDistributorsSubOrderId(String distributorsSubOrderId) {
        this.distributorsSubOrderId = distributorsSubOrderId;
    }
}

==> supplier-center-api-1.0.57-20230721.022314-3-sources.jar: cn/com/duiba/supplier/center/api/request/order/SupplyOrderInfoRequest.java <==
package cn.com.duiba.supplier.center.api.request.order;

import java.io.Serializable;

/**
 * @author duiba
 */
public class SupplyOrderInfoRequest implements Serializable {
    private static final long serialVersionUID = 3169590830373150562L;

    /**
     * 采购单订单号 必填
     */
    private Long supplyOrderNum;
    /**
     * 供应商父订单号
     */
    private String supplierParentOrderId;
    /**
     * 供应商子订单号
     */
    private String supplierSubOrderId;
    /**
     * 分销商父订单号
     */
    private String distributorsParentOrderId;
    /**
     * 分销商子订单号
     */
    private String distributorsSubOrderId;

    /**
     * 充值账号
     */
    private String rechargeAccount;

    /**
     * 扩展字段 保存重试的一些参数
     */
    private String expressInfo;

    public String getRechargeAccount() {
        return rechargeAccount;
    }

    public void setRechargeAccount(String rechargeAccount) {
        this.rechargeAccount = rechargeAccount;
    }

    public String getExpressInfo() {
        return expressInfo;
    }

    public void setExpressInfo(String expressInfo) {
        this.expressInfo = expressInfo;
    }

    public Long getSupplyOrderNum() {
        return supplyOrderNum;
    }

    public void setSupplyOrderNum(Long supplyOrderNum) {
        this.supplyOrderNum = supplyOrderNum;
    }

    public String getSupplierParentOrderId() {
        return supplierParentOrderId;
    }

    public void setSupplierParentOrderId(String supplierParentOrderId) {
        this.supplierParentOrderId = supplierParentOrderId;
    }

    public String getSupplierSubOrderId() {
        return supplierSubOrderId;
    }

    public void setSupplierSubOrderId(String supplierSubOrderId) {
        this.supplierSubOrderId = supplierSubOrderId;
    }

    public String getDistributorsParentOrderId() {
        return distributorsParentOrderId;
    }

    public void setDistributorsParentOrderId(String distributorsParentOrderId) {
        this.distributorsParentOrderId = distributorsParentOrderId;
    }

    public String getDistributorsSubOrderId() {
        return distributorsSubOrderId;
    }

    public void setDistributorsSubOrderId(String distributorsSubOrderId) {
        this.distributorsSubOrderId = distributorsSubOrderId;
    }
}
